<?php

namespace App\Http\Controllers;

use App\CustomerProperty;
use App\CustomerStatement;
use App\DirectBallotingMapDetail;
use Illuminate\Http\Request;
use App\DirectBallotingMapFile;
use App\Imports\ImportDirectMapFileData;
use App\Inventory;
use App\InventoryCategory;
use App\MultiProject;
use App\Rules\DirectExcelMapFileRule;
use Maatwebsite\Excel\Facades\Excel;
use App\Traits\MultiProjectCookie;
use Illuminate\Support\Facades\Validator;
use DB;

class DirectBallotingController extends Controller
{
    use MultiProjectCookie;
    
    public function directBalloting()
    {
        $balloting_files = DirectBallotingMapFile::get();
        return view('balloting.direct.index', compact('balloting_files'));
       
    }

    public function  directSettingAddFile()
    {

        $data =  $this->getCookieInfoAndMultiPro();
      
        if ($data['status'] == 'error') {
            return redirect()

                ->back()
                ->with([
                    'message' => 'Invalid Inputs!',
                    'alert-type' => 'error',
                ]);
        }

        return view('balloting.direct.add', $data);
    }

    public function downloadDirectBallotingFormate()
    {
        $filename =  'directexample.xlsx';
        $path = 'excel/' . 'directexample.xlsx';

        return response()->download(storage_path('app/' . $path), $filename, [
            'Content-Type' => 'application/vnd.ms-excel',
        ]);
    }

    public function storeDirectMapFile(Request $request)
    { 
           

        $this->validate($request, [

            'multipro_id'=>'required',
            'name' => 'required',
            'description' => 'nullable|min:3|max:1000',
            'mapfile' => ['required', 'file', new DirectExcelMapFileRule],
        ]);
        
        $dec_pro_id =  $request->cookie('current_project_id');
        if (empty($dec_pro_id)) {
            return redirect()

                ->back()
                ->with([
                    'message' => 'Something went wrong!',
                    'alert-type' => 'error',
                ]);
        }

        $pro_id = decrypt($dec_pro_id);
        $multi_pro = MultiProject::whereRaw("id = IF(name='Super Admin', $pro_id, -1)")->first();

        if (!empty($multi_pro)) {
            $validator = Validator::make($request->all(), [
                'multipro_id' => 'required',
            ]);
            if ($validator->fails()) {
                return redirect()
                    ->back()
                    ->withErrors($validator)->withInput();
            }
        } else {
            $request->merge(['multipro_id' =>  $dec_pro_id]);
        }

        if ($validator->fails()) {
            return redirect()
                ->back()
                ->withErrors($validator)->withInput();
        }



        $project_id = decrypt($request->multipro_id);


        $file = $request->file('mapfile');

        $filename = time() . '_' . $file->getClientOriginalName();

        // $path = $file->storeAs('excel', $filename, 'public');
        $path = $file->storeAs('excel', $filename, 'local');

        $balloting_file = new DirectBallotingMapFile;
        $balloting_file->multi_project_id = $project_id;
      
        $balloting_file->name = $request->name;
        $balloting_file->description = $request->description;
        $balloting_file->status = 0;
        $balloting_file->path = $path;
        $balloting_file->file_name = $filename;
        $balloting_file->save();
        return redirect()
            ->route('balloting.direct.index')
            ->with([
                'message' => 'Data Added Successfully!',
                'alert-type' => 'success'
            ]);
    }

    public function directBallotingPublishMap($id)
    {
        $balloting_file = DirectBallotingMapFile::where('id', $id)->first();
        
        return view('balloting.direct.publish', compact('balloting_file'));
    }

    public function importDirectBallotingMapFileData(Request $request)
    {
          try {
            $balloting_file = DirectBallotingMapFile::where('id', $request->map_id)->first();


            $data = Excel::toArray([], storage_path('app/' . $balloting_file->path))[0];
            $total_row = sizeof($data);
            $path = storage_path('app/' . $balloting_file->path);
           
            
            Excel::import(new ImportDirectMapFileData($balloting_file->id, $total_row), storage_path('app/' . $balloting_file->path));
           
            $balloting_file = DirectBallotingMapFile::where('id', $request->map_id)->first();

            $balloting_file->publish = 1;
            $balloting_file->save();
           
            session(['progress' => 100]);
            return response()->json([
                'success' => true,
                'message' => 'Data Published Successfully'
            ]);
        } catch (\Exception $e) {

            return response()->json([
                'error' => true,
                'message' => 'Something went wrong'
            ], 500);
        }
    }

    public function viewMapFile($id)
    {
        $file =    DirectBallotingMapFile::where('id', $id)->first();
        $filename =  $file->file_name;
        $path = 'excel/' . $filename;
        $data = Excel::toArray([], storage_path('app/' . $path))[0];
        return view('balloting.setting.view', compact('data'));
    }

    public function startBalloting($id)
    {
    
        $balloting_file =    DirectBallotingMapFile::where('id', $id)->first();
    
        return view('balloting.direct.start', compact('balloting_file'));
    }

    public function startBallotingMap(Request $request)
    {
         
        
        
        $b = new DirectBallotingMapDetail;
        $val = $b->startBallotingInventory($request);
        if ($val['status'] == true) {
            return response()->json([
                'success' => true,
                'message' => 'Data Published Successfully',
                'id' => $val['id']
            ]);
        } else {
            return response()->json([
                'success' => false,
                'message' => 'SomeThing went wrong'
            ]);
        }
    }

    public function  publishMapInventory($id)
    {
        $balloting_file = DirectBallotingMapFile::where('id', $id)->first();
        
        return view('balloting.direct.view', compact('balloting_file'));
    }

    public function downloadFileFormate2($id)
    {
        $file =    DirectBallotingMapFile::where('id', $id)->first();
        $filename =  $file->file_name;
        $path = 'excel/' . $filename;

        return response()->download(storage_path('app/' . $path), $filename, [
            'Content-Type' => 'application/vnd.ms-excel',
        ]);
    }

    public function editMapInventory($id)
    {



        $ball_detail = DirectBallotingMapDetail::where('id', $id)->first();
        $request = app(Request::class);
        $request->merge([
            'multipro_id' => encrypt($ball_detail->map->multi_project_id),

        ]);
       
        $data =  $this->getCookieInfoAndMultiPro();
 
        if ($data['status'] == 'error') {
            return redirect()
                ->back()
                ->with([
                    'message' => 'Invalid Inputs!',
                    'alert-type' => 'error',
                ]);
        }
        $ids = [];
        if (is_array($data['project_ids'])) {
            $ids =    $data['project_ids'];
        } else {
            $ids[] =    $data['project_ids'];
        }

        if ($ids[0] == $ball_detail->map->multi_project_id || $ids[0] == 'all') {
            if ($ids[0] != 'all') {
                $multipro_id =  $ball_detail->map->multi_project_id;
            } else {
                $multipro_id = 'all';
            }
            return view('balloting.direct.edit', compact('ball_detail', 'multipro_id'));
        } else {
            return redirect()

                ->route('home')
                ->with([
                    'message' => 'UnAuthorized Action!',
                    'alert-type' => 'error',
                ]);
        }

        


    }

    public function updateMapInventory(Request $request)
    {


        $this->validate($request, [

            'id' => 'required',
            'customer_property' => 'required',

        ]);
        $ball_map_detail =  DirectBallotingMapDetail::where('id', $request->id)->first();
        $inventory =  Inventory::where('id', $request->customer_property)->first();
        
        if ($ball_map_detail->unit_size_id == $inventory->unit_size_id) {
            $ball_map_detail->inventory_id = $inventory->id;
            $ball_map_detail->balloting_status = DirectBallotingMapDetail::balloting_pending;
            $ball_map_detail->save();
            $inventory = Inventory::where('id', $inventory->id)->first();

            $old_unit_number = $inventory->unit_number;
            $inventory->unit_number = $ball_map_detail->plot_no;
            $inventory->unit_floor_id = $ball_map_detail->unit_floor_id;
            $inventory->old_unit_number = $old_unit_number;
            $inventory->inventory_type = Inventory::allocated;
            $inventory->save();
            // $ballondetail =  BallotingPreConditionFileDetail::where('inventory_id', $inventory->id)->get();
            // foreach ($ballondetail as $detail) {
            //     $detail->balloting_map_detail_id = $ball_map_detail->id;
            //     $detail->save();
            // }

            if (!empty($ball_map_detail->category)) {
                foreach ($ball_map_detail->category as $r) {

                    InventoryCategory::create(['inventory_id' => $inventory->id, 'unit_category_id' => $r->category_id]);
                }
            }

            return redirect()
                ->back()
                ->with([
                    'message' => 'Data Updated Successfully!',
                    'alert-type' => 'success'
                ]);
        }
        return redirect()
            ->back()
            ->with([
                'message' => 'Sizes Mismatch!',
                'alert-type' => 'error'
            ]);
    }

    public function approveBalloting($id)
    {
        $balloting_detail =     DirectBallotingMapDetail::where('id', $id)->where('balloting_status', DirectBallotingMapDetail::balloting_pending)->first();
        if (!empty($balloting_detail)) {
            if ($balloting_detail->inventory_id) {
                $inventory = Inventory::with('categories', 'size', 'floor', 'type')->where('id', $balloting_detail->inventory_id)->first();
                $sum = 0;
                if (sizeof($inventory->categories) > 0) {
                    foreach ($inventory->categories as $c) {

                        if ($c->is_percent) {
                            $sum += ($inventory->total_price * $c->percent) / 100;
                        } else {
                            $sum +=  $c->percent;
                        }
                    }
                }


                return view('balloting.direct.approve', compact('sum', 'inventory', 'balloting_detail'));
            }
        }
        else{
            return redirect()->back()
            ->with([
                'message' => 'SomeThing went wrong!',
                'alert-type' => 'error'
            ]);
        }
    }

    public function storeApproveBalloting(Request $request)
    {
       

        $this->validate($request, [

            'add_charges' => 'required|numeric',
            'balloting_id' => 'required|numeric',
            
        ]);
      
        if($request->add_charges == 1){
            $this->validate($request, [
               
                'custom_date.*' => 'required',
                'custom_amount.*' => 'required',
            ]);    

        }
        // dd($request->all());
        DB::beginTransaction();
        try{

            $balloting_detail =     DirectBallotingMapDetail::where('id', $request->balloting_id)->where('balloting_status', DirectBallotingMapDetail::balloting_pending)->first();
       
            if(!empty($balloting_detail)){
            $balloting_detail->balloting_status = DirectBallotingMapDetail::balloting_complete;
            $balloting_detail->save();
            $sum = 0;
            if($request->add_charges == 1){
            $customer_property=    $balloting_detail->Inventory->customer_property;
            $last_balloting_amount   =  CustomerStatement::where('customer_id', $customer_property->customer_id)->where( 'customer_property_id',$customer_property->id)->where('payment_head' , CustomerStatement::balloting) ->latest('id')
            ->first();
            $last_balloting_amount_inst_no=0;
            if(!empty($last_balloting_amount)){
                $cleanString = preg_replace('/[^0-9]/', '', $last_balloting_amount->inst_no);
                $last_balloting_amount_inst_no = (int) $cleanString;
            }

                for($i=0;$i < sizeof($request->custom_date) ; $i++ ){

                    $last_balloting_amount_inst_no =   $last_balloting_amount_inst_no +1;
                  $sum = $sum + $request->custom_amount[$i];
                        
                          CustomerStatement::create(['customer_id' => $customer_property->customer_id, 'customer_property_id' => $customer_property->id, 'payment_head' => CustomerStatement::balloting, 'inst_no' =>   $last_balloting_amount_inst_no, 'due_date' => $request->custom_date[$i], 'due' => $request->custom_amount[$i], 'balance' => $request->custom_amount[$i], 'received' => 0]);
               
            }
            $property=CustomerProperty::where('id', $customer_property->id)->first();
            $property->net_pay =  $property->net_pay + $sum; 
            $property->save();
            $inventory=  Inventory::where('id', $balloting_detail->inventory_id)->first();
            $inventory->extra_amount = $inventory->extra_amount+ $sum;
            $inventory->total_price =  $inventory->total_price +  $sum;
            $inventory->save();
                //  dd($balloting_detail,$balloting_detail->Inventory->customer_property);
                 // 
              //  $property = CustomerProperty::where()
                 //Make Bulleting payment entry
                //  
            }
            }
            
         

        }
        catch (\Exception $e) {

             
            DB::rollback();
            return redirect()->route('balloting.direct.map.inventory',$balloting_detail->direct_balloting_map_file_id)
        ->with([
            'message' => 'SomeThing went wrong!',
            'alert-type' => 'error'
        ]);
        }
        DB::commit();
        
        return redirect()
        ->route('balloting.direct.map.inventory', $balloting_detail->direct_balloting_map_file_id)
        ->with([
            'message' => 'Property Approved Sucessfully!',
            'alert-type' => 'success'
        ]);
       
    }

    public Function approveAllBallotingResult(Request $request)
    {

        // dd($request->all());
        $balloting_file = DirectBallotingMapFile::where('id', $request->id)->first();

        DB::beginTransaction();
        try{
            foreach($balloting_file->mapDetail as $map_detail){
                $balloting_detail =     DirectBallotingMapDetail::where('id', $map_detail->id)->where('balloting_status', DirectBallotingMapDetail::balloting_pending)->first();
       
                if(!empty($balloting_detail)){
                $balloting_detail->balloting_status = DirectBallotingMapDetail::balloting_complete;
                $balloting_detail->save();
                $sum = 0;
                // if($request->add_charges == 1){
                $customer_property=    $balloting_detail->Inventory->customer_property;
                $last_balloting_amount   =  CustomerStatement::
                where('customer_id', $customer_property->customer_id)
                ->where( 'customer_property_id',$customer_property->id)
                ->where('payment_head' , CustomerStatement::balloting)
                ->latest('id')
                ->first();
                  $category_amount = 0;

                  $inventory=  Inventory::where('id', $balloting_detail->inventory_id)->first();

                  foreach ($inventory->categories as $c){
                      if($c->category->is_percent == 1){        
                          $percentage = $c->category->percent;  // Set the desired percentage
                          $totalPrice = $inventory->total_price; // Get the total price from your inventory
                          $percentageAmount = ($percentage / 100) * $totalPrice;
                           $sum +=$percentageAmount;
                      }
                      else{
                     $sum += $c->category->percent; 
                      }
                  }
                $last_balloting_amount_inst_no=0;
                if(!empty($last_balloting_amount)){
                    $cleanString = preg_replace('/[^0-9]/', '', $last_balloting_amount->inst_no);
                    $last_balloting_amount_inst_no = (int) $cleanString;
                }
    
                    // for($i=0;$i < sizeof($request->custom_date) ; $i++ ){
    
                        $last_balloting_amount_inst_no =   $last_balloting_amount_inst_no +1;
                     
                            
                        CustomerStatement::create(['customer_id' => $customer_property->customer_id, 'customer_property_id' => $customer_property->id, 
                        'payment_head' => CustomerStatement::balloting,
                        'inst_no' =>   $last_balloting_amount_inst_no, 
                    //    'due_date' => $request->custom_date[$i],
                        'due' => $sum, 
                        'balance' => $sum, 'received' => 0]);
            
                // }
                $property=CustomerProperty::where('id', $customer_property->id)->first();
                $property->cost = $property->cost + $sum;
                $property->net_pay =  $property->net_pay + $sum; 
                $property->save();
                $inventory=  Inventory::where('id', $balloting_detail->inventory_id)->first();
                $inventory->extra_amount = $inventory->extra_amount+ $sum;
                $inventory->total_price =  $inventory->total_price +  $sum;
                $inventory->save();
                }
                }
            // }

          
            
         

        }
        catch (\Exception $e) {

             
            DB::rollback();
            return response()->json([
                'error' => true,
                'message' => 'Something went wrong'
            ], 500);
        }
        DB::commit();
        return response()->json([
            'success' => true,
            'message' => 'Balloting Approved Successfully'
        ]);
        
    }

    public function removeMapFileInventory(Request $request)
    {

        try {
            $ball_map_detail = DirectBallotingMapDetail::where('id', $request->id)->first();


            $inventory =  Inventory::where('id', $ball_map_detail->inventory_id)->first();
            
            $inventory->unit_number =   $inventory->old_unit_number; 
        
            $ball_map_detail->inventory_id = null;
            $ball_map_detail->balloting_status = DirectBallotingMapDetail::not_ballot_yet;
            $ball_map_detail->save();
            
            // $inventory = Inventory::where('id', $customer_pro->inventory_id)->first();
            $inventory->unit_floor_id = null;
            $inventory->inventory_type = Inventory::unallocated;
            $inventory->save();

            if (!empty($ball_map_detail->category)) {
                foreach ($ball_map_detail->category as $r) {

                    $inventory_cat = InventoryCategory::where('inventory_id', $inventory->id)->where('unit_category_id', $r->category_id)->first();
                    if ($inventory_cat->percent == 0 && $inventory_cat->is_percent == 0) {
                        $inventory_cat->delete();
                    }
                }
            }

            return response()->json([
                'success' => true,
                'message' => 'Data Removed Successfully'
            ]);
        } catch (\Exception $e) {
            return response()->json([
                'error' => true,
                'message' => 'Something went wrong'
            ], 500);
        }
    }

    //
}
